@@ -2,18 +2,20 @@
 
 import logging
 import os
+import pprint
 from datetime import datetime, timedelta
 from itertools import islice
 from time import sleep, time
 from typing import Dict, List, Tuple
-import pprint
 
 import requests
 
 from yojenkins.monitor import BuildMonitor
 from yojenkins.utility import utility
 from yojenkins.utility.utility import fail_out, print2
+from yojenkins.yo_jenkins.auth import Auth
 from yojenkins.yo_jenkins.jenkins_item_classes import JenkinsItemClasses
+from yojenkins.yo_jenkins.rest import Rest
 from yojenkins.yo_jenkins.status import BuildStatus
 
 # Getting the logger reference
@@ -23,7 +25,7 @@ logger = logging.getLogger()
 class Build():
     """Buld class"""
 
-    def __init__(self, rest, auth) -> None:
+    def __init__(self, rest: Rest, auth: Auth) -> None:
         """Object constructor method, called at object creation
 
         Args:
